dustmap modules
===============

.. toctree::
    :maxdepth: 4


bayestar (Green et al. 2015, 2018)
----------------------------------
.. automodule:: dustmaps.bayestar
    :members:
    :special-members:
    :show-inheritance:

decaps (Zucker, Saydjari, & Speagle et al. 2025)
----------------------------------
.. automodule:: dustmaps.bayestar
    :members:
    :special-members:
    :show-inheritance:


bh (Burstein & Heiles 1982)
---------------------------
.. automodule:: dustmaps.bh
    :members:
    :special-members:
    :show-inheritance:

chen2014 (Chen et al. 2014)
---------------------------
.. automodule:: dustmaps.chen2014
    :members:
    :special-members:
    :show-inheritance:

csfd (Chiang 2023)
---------------------------
.. automodule:: dustmaps.csfd
    :members:
    :special-members:
    :show-inheritance:

gaia_tge (Delchambre et al. 2022)
---------------------------
.. automodule:: dustmaps.gaia_tge
    :members:
    :special-members:
    :show-inheritance:

iphas (Sale et al. 2014)
------------------------
.. automodule:: dustmaps.iphas
    :members:
    :special-members:
    :show-inheritance:

leike_ensslin_2019 (Leike & Enßlin 2019)
----------------------------------------
.. automodule:: dustmaps.leike_ensslin_2019
    :members:
    :special-members:
    :show-inheritance:

leike2020 (Leike, Glatzle & Enßlin 2020)
----------------------------------------
.. automodule:: dustmaps.leike2020
    :members:
    :special-members:
    :show-inheritance:

edenhofer2023 (Edenhofer et al. 2023)
-------------------------------------
.. automodule:: dustmaps.edenhofer2023
    :members:
    :special-members:
    :show-inheritance:

lenz2017 (Lenz, Hensley & Doré 2017)
------------------------------------
.. automodule:: dustmaps.lenz2017
    :members:
    :special-members:
    :show-inheritance:

marshall (Marshall et al. 2006)
-------------------------------
.. automodule:: dustmaps.marshall
    :members:
    :special-members:
    :show-inheritance:

pg2010 (Peek & Graves 2010)
---------------------------
.. automodule:: dustmaps.pg2010
    :members:
    :special-members:
    :show-inheritance:

planck (Planck Collaboration 2013, 2016)
----------------------------------------
.. automodule:: dustmaps.planck
    :members:
    :special-members:
    :show-inheritance:


sfd (Schlegel, Finkbeiner & Davis 1998)
---------------------------------------
.. automodule:: dustmaps.sfd
    :members:
    :special-members:
    :show-inheritance:


fetch_utils
-----------
.. automodule:: dustmaps.fetch_utils
    :members:
    :special-members:
    :show-inheritance:


map_base
--------
.. automodule:: dustmaps.map_base
    :members:
    :special-members: __call__
    :show-inheritance:


healpix_map
-----------
.. automodule:: dustmaps.healpix_map
    :members:
    :special-members:
    :show-inheritance:


unstructured_map
----------------
.. automodule:: dustmaps.unstructured_map
    :members:
    :special-members:
    :show-inheritance:


config
------
.. automodule:: dustmaps.config
    :members:
    :show-inheritance:


std_paths
---------
.. automodule:: dustmaps.std_paths
    :members:
    :special-members:
    :show-inheritance:


json_serializers
----------------
.. automodule:: dustmaps.json_serializers
    :members:
    :special-members:
    :show-inheritance:
